/**
 * TicketMachine models a ticket machine that issues
 * flat-fare tickets.
 * The price of a ticket is specified via the constructor.
 * Instances will check to ensure that a user only enters
 * sensible amounts of money, and will only print a ticket
 * if enough money has been input.
 * 
 * This version has no output to the console window other
 * than the printing of the ticket.
 * @author David J. Barnes and Michael Kolling
 * @author John Pagliarulo 
 * @version 2005.03.01
 */

public class TicketMachine
{
    // The price of a ticket from this machine.
    private int price;
    // The amount of money entered by a customer so far.
    private int balance;
    // The total amount of money collected by this machine.
    private int total;

    /**
     * Create a machine that issues tickets of the given price.
     * @param the price of the ticket
     */
    public TicketMachine(int ticketCost)
    {
        price = ticketCost;
        balance = 0;
        total = 0;
    }

    /**
     * @return The price of a ticket.
     */
    public int getPrice()
    {
        return price;
    }

    /**
     * @return The amount of money inserted for the ticket.
     */
    public int getBalance()
    {
        return balance;
    }

    /**
     * Receive an amount of money in cents from a customer.
     * If amount is <= 0 it is ignored.
     * @param the amount of money inserted (in cents)
     *
     */
    public void insertMoney(int amount)
    {
        if(amount > 0) {
            balance = balance + amount;
        }
        return;
    }

    /**
     * Print a ticket if enough money has been inserted, and
     * reduce the current balance by the ticket price. 
     */
    public void printTicket()
    {
        if(balance >= price) {
            // Simulate the printing of a ticket.
            System.out.println("##################");
            System.out.println("# The BlueJ Line");
            System.out.println("# Ticket");
            System.out.println("# " + price + " cents.");
            System.out.println("##################");
            System.out.println();

            // Update the total collected with the price.
            total = total + price;
            // Reduce the balance by the prince.
            balance = balance - price;
        }
                             
    }

    /**
     * Gives change to the user
     * Balance is reset to 0
     * @return the balance of money in the machine
     */
    public int refundBalance()
    {
        int amountToRefund;
        amountToRefund = balance;
        balance = 0;
        return amountToRefund;
    }
    
    /** Empty the money in the machine
     *  Total is reset to 0
     *  @return the total amount of money in the machine
     */
    public int emptyMachine()
    {
        int amountInMachine;
        
        amountInMachine = total;
        total = 0;
        return amountInMachine;
    }

}
